@@ -17,7 +17,12 @@ if (authenticated) {
     test_that("State Array Upload", {
         df <- read.csv("./data/states.csv")
         expect_no_error(
-            s1 <<- auto_discover(token, geo_grain = "State", df = df)$signal_id
+            s1 <<- auto_discover(
+                token,
+                geo_grain = "State",
+                date_grain = "Month",
+                df = df
+            )$signal_id
         )
     })
 
@@ -25,21 +30,48 @@ if (authenticated) {
     test_that("Country Array Upload", {
         df <- read.csv("./data/country.csv")
         expect_no_error(
-            s2 <<- auto_discover(token, geo_grain = "Country", df = df)$signal_id
+            s2 <<- auto_discover(
+                token,
+                geo_grain = "Country",
+                date_grain = "Month",
+                df = df
+            )$signal_id
         )
     })
 
     s3 <- NULL
     test_that("State File Upload", {
         expect_no_error(
-            s3 <<- auto_discover(token, geo_grain = "State", filename = "./data/states.csv")$signal_id
+            s3 <<- auto_discover(
+                token,
+                geo_grain = "State",
+                date_grain = "Month",
+                filename = "./data/states.csv"
+            )$signal_id
         )
     })
 
     s4 <- NULL
     test_that("Country File Upload", {
         expect_no_error(
-            s4 <<- auto_discover(token, geo_grain = "Country", filename = "./data/country.csv")$signal_id
+            s4 <<- auto_discover(
+                token,
+                geo_grain = "Country",
+                date_grain = "Month",
+                filename = "./data/country.csv"
+            )$signal_id
+        )
+    })
+
+    s5 <- NULL
+    test_that("Day File Upload", {
+        expect_no_error(
+            s5 <<- auto_discover(
+                token,
+                geo_grain = "Country",
+                date_grain = "Day",
+                filename = "./data/day.csv"
+            )$signal_id
         )
     })
 
@@ -49,5 +81,6 @@ if (authenticated) {
         expect_no_error(delete_signal(token, s2))
         expect_no_error(delete_signal(token, s3))
         expect_no_error(delete_signal(token, s4))
+        expect_no_error(delete_signal(token, s5))
     })
 }
\ No newline at end of file
